from typing import Literal

Translate = Literal[
    'x-0',
    'y-0',
    'x-px',
    'y-px',
    'x-0.5',
    'y-0.5',
    'x-1',
    'y-1',
    'x-1.5',
    'y-1.5',
    'x-2',
    'y-2',
    'x-2.5',
    'y-2.5',
    'x-3',
    'y-3',
    'x-3.5',
    'y-3.5',
    'x-4',
    'y-4',
    'x-5',
    'y-5',
    'x-6',
    'y-6',
    'x-7',
    'y-7',
    'x-8',
    'y-8',
    'x-9',
    'y-9',
    'x-10',
    'y-10',
    'x-11',
    'y-11',
    'x-12',
    'y-12',
    'x-14',
    'y-14',
    'x-16',
    'y-16',
    'x-20',
    'y-20',
    'x-24',
    'y-24',
    'x-28',
    'y-28',
    'x-32',
    'y-32',
    'x-36',
    'y-36',
    'x-40',
    'y-40',
    'x-44',
    'y-44',
    'x-48',
    'y-48',
    'x-52',
    'y-52',
    'x-56',
    'y-56',
    'x-60',
    'y-60',
    'x-64',
    'y-64',
    'x-72',
    'y-72',
    'x-80',
    'y-80',
    'x-96',
    'y-96',
    'x-1/2',
    'x-1/3',
    'x-2/3',
    'x-1/4',
    'x-2/4',
    'x-3/4',
    'x-full',
    'y-1/2',
    'y-1/3',
    'y-2/3',
    'y-1/4',
    'y-2/4',
    'y-3/4',
    'y-full',
]
